@@ -1,4 +1,4 @@
-/* pg_fact_loader--1.5--1.6.sql */
+/* pg_fact_loader--1.6--1.7.sql */
 
 -- complain if script is sourced in psql, rather than via CREATE EXTENSION
 \echo Use "CREATE EXTENSION pg_fact_loader" to load this file. \quit
@@ -7,33 +7,87 @@ DROP VIEW fact_loader.queue_deps_all_with_retrieval;
 DROP VIEW fact_loader.queue_deps_all;
 DROP VIEW fact_loader.prioritized_jobs;
 
--- Must ensure we have the fully schema-qualified regprod before converting to text
-SET search_path TO '';
-ALTER TABLE fact_loader.debug_process_queue ALTER COLUMN proid TYPE TEXT;
-ALTER TABLE fact_loader.debug_process_queue ADD CONSTRAINT check_proid CHECK (COALESCE(proid::REGPROC, 'boolin') IS NOT NULL);
-ALTER TABLE fact_loader.fact_table_dep_queue_table_deps ALTER COLUMN delete_merge_proid TYPE TEXT;
-ALTER TABLE fact_loader.fact_table_dep_queue_table_deps ADD CONSTRAINT check_delete_merge_proid CHECK (COALESCE(delete_merge_proid::REGPROC, 'boolin') IS NOT NULL);
-ALTER TABLE fact_loader.fact_table_dep_queue_table_deps ALTER COLUMN insert_merge_proid TYPE TEXT;
-ALTER TABLE fact_loader.fact_table_dep_queue_table_deps ADD CONSTRAINT check_insert_merge_proid CHECK (COALESCE(insert_merge_proid::REGPROC, 'boolin') IS NOT NULL);
-ALTER TABLE fact_loader.fact_table_dep_queue_table_deps ALTER COLUMN update_merge_proid TYPE TEXT;
-ALTER TABLE fact_loader.fact_table_dep_queue_table_deps ADD CONSTRAINT check_update_merge_proid CHECK (COALESCE(update_merge_proid::REGPROC, 'boolin') IS NOT NULL);
-ALTER TABLE fact_loader.fact_table_deps ALTER COLUMN default_delete_merge_proid TYPE TEXT;
-ALTER TABLE fact_loader.fact_table_deps ADD CONSTRAINT check_default_delete_merge_proid CHECK (COALESCE(default_delete_merge_proid::REGPROC, 'boolin') IS NOT NULL);
-ALTER TABLE fact_loader.fact_table_deps ALTER COLUMN default_insert_merge_proid TYPE TEXT;
-ALTER TABLE fact_loader.fact_table_deps ADD CONSTRAINT check_default_insert_merge_proid CHECK (COALESCE(default_insert_merge_proid::REGPROC, 'boolin') IS NOT NULL);
-ALTER TABLE fact_loader.fact_table_deps ALTER COLUMN default_update_merge_proid TYPE TEXT;
-ALTER TABLE fact_loader.fact_table_deps ADD CONSTRAINT check_default_update_merge_proid CHECK (COALESCE(default_update_merge_proid::REGPROC, 'boolin') IS NOT NULL);
-ALTER TABLE fact_loader.fact_tables ALTER COLUMN daily_scheduled_proid TYPE TEXT;
-ALTER TABLE fact_loader.fact_tables ADD CONSTRAINT check_daily_scheduled_proid CHECK (COALESCE(daily_scheduled_proid::REGPROC, 'boolin') IS NOT NULL);
-ALTER TABLE fact_loader.fact_tables ALTER COLUMN fact_table_agg_proid TYPE TEXT;
-ALTER TABLE fact_loader.fact_tables ADD CONSTRAINT check_fact_table_agg_proid CHECK (COALESCE(fact_table_agg_proid::REGPROC, 'boolin') IS NOT NULL);
-ALTER TABLE fact_loader.queue_table_deps ALTER COLUMN delete_merge_proid TYPE TEXT;
-ALTER TABLE fact_loader.queue_table_deps ADD CONSTRAINT check_delete_merge_proid CHECK (COALESCE(delete_merge_proid::REGPROC, 'boolin') IS NOT NULL);
-ALTER TABLE fact_loader.queue_table_deps ALTER COLUMN insert_merge_proid TYPE TEXT;
-ALTER TABLE fact_loader.queue_table_deps ADD CONSTRAINT check_insert_merge_proid CHECK (COALESCE(insert_merge_proid::REGPROC, 'boolin') IS NOT NULL);
-ALTER TABLE fact_loader.queue_table_deps ALTER COLUMN update_merge_proid TYPE TEXT;
-ALTER TABLE fact_loader.queue_table_deps ADD CONSTRAINT check_update_merge_proid CHECK (COALESCE(update_merge_proid::REGPROC, 'boolin') IS NOT NULL);
-RESET search_path;
+ALTER TABLE fact_loader.fact_tables ADD COLUMN pre_execute_hook_sql TEXT;
+
+
+CREATE OR REPLACE FUNCTION fact_loader.load(p_fact_table_id INT)
+RETURNS VOID AS
+$BODY$
+DECLARE
+    v_process_queue_sql text;
+    v_execute_sql text;
+    v_metadata_update_sql text;
+    v_debug_rec record;
+    v_debug_text text = '';
+    v_pre_execute_hook_sql text = '';
+BEGIN
+/***
+There are 3 basic steps to this load:
+    1. Gather all queue table changes and insert them into a consolidated process_queue
+    2. Update the metadata indicating the last records updated for both the queue tables and fact table
+ */
+
+/****
+Get SQL to insert new data into the consolidated process_queue,
+and SQL to update metadata for last_cutoffs.
+ */
+SELECT process_queue_sql, metadata_update_sql
+INTO v_process_queue_sql, v_metadata_update_sql
+FROM fact_loader.sql_builder(p_fact_table_id);
+
+/****
+Populate the consolidated queue
+This just creates a temp table with all changes to be processed
+ */
+RAISE DEBUG 'Populating Queue for fact_table_id %: %', p_fact_table_id, v_process_queue_sql;
+EXECUTE COALESCE(v_process_queue_sql, $$SELECT 'No queue data' AS result$$);
+
+/****
+ Pre-execute hook
+ */
+SELECT pre_execute_hook_sql INTO v_pre_execute_hook_sql
+FROM fact_loader.fact_tables
+WHERE fact_table_id = p_fact_table_id;
+
+EXECUTE COALESCE(v_pre_execute_hook_sql, $$SELECT 'No pre-execute hook.' AS result$$);
+
+/****
+For DEBUG purposes only to view the actual process_queue.  Requires setting log_min_messages to DEBUG.
+ */
+IF current_setting('log_min_messages') = 'debug3' THEN
+    INSERT INTO fact_loader.debug_process_queue (process_queue_id, fact_table_id, proid, key_value, row_created_at, row_updated_at, source_change_date)
+    -- the row timestamps are not populated, so we set them here
+    SELECT process_queue_id, fact_table_id, proid, key_value, now(), now(), source_change_date FROM process_queue;
+END IF;
+
+/****
+With data now in the process_queue, the execute_queue function builds the SQL to execute.
+Save this SQL in a variable and execute it.
+If there is no data to execute, this is a no-op select statement.
+ */
+SELECT sql INTO v_execute_sql FROM fact_loader.execute_queue(p_fact_table_id);
+RAISE DEBUG 'Executing Queue for fact_table_id %: %', p_fact_table_id, v_execute_sql;
+EXECUTE COALESCE(v_execute_sql, $$SELECT 'No queue data to execute' AS result$$);
+
+/****
+With everything finished, we now update the metadata for the fact_table.
+Even if no data was processed, we will still move forward last_refresh_attempted_at.
+
+last_refresh_succeeded will be marked true always for now.  It could in the future
+be used to indicate a failure in case of a caught error.
+ */
+RAISE DEBUG 'Updating metadata for fact_table_id %: %', p_fact_table_id, v_metadata_update_sql;
+EXECUTE COALESCE(v_metadata_update_sql,
+    format(
+    $$UPDATE fact_loader.fact_tables ft
+        SET last_refresh_attempted_at = now(),
+          last_refresh_succeeded = TRUE
+     WHERE fact_table_id = %s;
+    $$, p_fact_table_id));
+
+END;
+$BODY$
+LANGUAGE plpgsql;
 
 
 CREATE OR REPLACE VIEW fact_loader.prioritized_jobs AS
